Index: LMDZ6/trunk/tools/compare_real.py
===================================================================
--- LMDZ6/trunk/tools/compare_real.py	(revision 4511)
+++ LMDZ6/trunk/tools/compare_real.py	(revision 4512)
@@ -1,5 +1,6 @@
+#!/usr/bin/env python3
+
 """This script should be called by "diffdef.sh". It operates on
-different lines with common variables. It requires version 2.7 or
-higher of Python (it also works with Python 3).
+different lines with common variables.
 
 Author: Lionel GUEZ"""
Index: LMDZ6/trunk/tools/diffdef.sh
===================================================================
--- LMDZ6/trunk/tools/diffdef.sh	(revision 4511)
+++ LMDZ6/trunk/tools/diffdef.sh	(revision 4512)
@@ -2,6 +2,6 @@
 # Author: Lionel GUEZ
 
 # This script compares files "*.def" other than "*traceur.def" and
 # "out.def" in two directories.
 
 # This script uses GNU versions of the utilities cut, sort and uniq,
@@ -9,10 +9,10 @@
 
 # See guide:
-# http://lmdz.lmd.jussieu.fr/utilisateurs/outils/utilisation-de-lmdz#section-5
+# http://lmdz.lmd.jussieu.fr/utilisateurs/utilisation-de-lmdz#section-5
 
 USAGE="usage: `basename $0` directory_1 directory_2"
 
 if (($# != 2))
-    then
+then
     echo "$USAGE" >&2
     exit 1
@@ -20,13 +20,4 @@
 
 ##set -x
-
-type python3 >/dev/null 2>&1
-if (($? == 0))
-then
-    my_python=python3
-else
-    my_python=python
-fi
-
 set -e
 
@@ -40,42 +31,44 @@
 
 for my_directory in $*
-  do
-  cd $my_directory
-  rm -f all.def
-  echo "def files in $my_directory:"
-  ls !(*traceur|out).def
+do
+    cd $my_directory
+    rm -f all.def
+    echo "def files in $my_directory:"
+    ls !(traceur|tracer|out|isotopes_params).def
 
-  # Concatenate and format the def files:
-  cat !(*traceur|out).def | tr '\r' '\n' | tr -d " " \
-      | grep -v -E '(^#|^!|INCLUDEDEF|^$)' \
-      | tr '[:lower:]' '[:upper:]' | sed 's/=[NF]$/=FALSE/' \
-      | sed 's/=[YT]$/=TRUE/' | sort >all.def
+    # Concatenate and format the def files:
+    cat !(traceur|tracer|out|isotopes_params).def | tr -d " \t" \
+	| grep -v -E '(^#|^!|INCLUDEDEF|^$)' \
+	| tr '[:lower:]' '[:upper:]' | sed 's/=[NF]$/=FALSE/' \
+	| sed 's/=[YT]$/=TRUE/' | sort >all.def
 
-  # Check that no variable is repeated:
-  cut --fields=1 --delimiter="=" all.def | uniq --repeated >plouf_$$
-  if [[ -s plouf_$$ ]]
-      then
-      echo
-      echo "Error: a variable is repeated in directory \"$my_directory\"."
-      echo
-      echo "Here is the list of repeated variables in directory \"$my_directory\":"
-      echo
-      cat plouf_$$
-      rm plouf_$$
-      rm all.def
-      exit 1
-  fi
-  rm plouf_$$
-
-  cd - >/dev/null
+    # Check that no variable is repeated:
+    
+    cut --fields=1 --delimiter="=" all.def | uniq --repeated >plouf_$$
+    
+    if [[ -s plouf_$$ ]]
+    then
+	echo
+	echo "Error: a variable is repeated in directory \"$my_directory\"."
+	echo
+	echo "Here is the list of repeated variables in directory " \
+	     "\"$my_directory\":"
+	echo
+	cat plouf_$$
+	rm plouf_$$
+	rm all.def
+	exit 1
+    fi
+    
+    rm plouf_$$
+    cd - >/dev/null
 done
-
 
 sort $1/all.def $2/all.def | uniq --repeated >common_lines
 
 for my_directory in $*
-  do
-  sort $my_directory/all.def common_lines | uniq --unique \
-      >$my_directory/uniq_lines
+do
+    sort $my_directory/all.def common_lines | uniq --unique \
+						   >$my_directory/uniq_lines
 done
 
@@ -86,13 +79,13 @@
 
 for my_directory in $*
-  do
-  cd $my_directory
-  echo "Created file \"$my_directory/uniq_var\"."
-  sort uniq_lines uniq_var | uniq --unique >common_var
-  rm uniq_lines
-  cd - >/dev/null
+do
+    cd $my_directory
+    echo "Created file \"$my_directory/uniq_var\"."
+    sort uniq_lines uniq_var | uniq --unique >common_var
+    rm uniq_lines
+    cd - >/dev/null
 done
 
-$my_python $script_dir/compare_real.py $*
+$script_dir/compare_real.py $*
 sort common_lines --output=common_lines # was modified by the Python script
 echo "Created files \"./common_lines\" and \"./uniq_val\"."
@@ -100,5 +93,5 @@
 # Clean up:
 for my_directory in $*
-  do
+do
     rm $my_directory/common_var $my_directory/all.def
 done
@@ -2,6 +2,6 @@
 # Author: Lionel GUEZ
 
-# This script compares files "*.def" other than "*traceur.def" and
-# "out.def" in two directories.
+# This script compares files "*.def" other than "traceur.def",
+# "tracer.def", "isotopes_params.def" and "out.def" in two directories.
 
 # This script uses GNU versions of the utilities cut, sort and uniq,
